@@ -1,6 +1,5 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-from __future__ import with_statement
 import uuid
 import vobject
 import dateutil.tz
@@ -10,8 +9,9 @@ import xml.dom.minidom
 from trytond.model import ModelSQL, ModelView, fields
 from trytond.tools import reduce_ids
 from trytond.backend import TableHandler
-from trytond.pyson import Not, Equal, Eval, If, Bool, In
+from trytond.pyson import Eval, If, Bool
 from trytond.transaction import Transaction
+from trytond.pool import Pool
 
 tzlocal = dateutil.tz.tzlocal()
 tzutc = dateutil.tz.tzutc()
@@ -34,23 +34,21 @@ class Todo(ModelSQL, ModelView):
         ('confidential', 'Confidential'),
         ], 'Classification', required=True)
     completed = fields.DateTime('Completed',
-            states={
-                'readonly': Not(Equal(Eval('status'), 'completed')),
+        states={
+            'readonly': Eval('status') != 'completed',
             }, depends=['status'])
     description = fields.Text('Description')
     dtstart = fields.DateTime('Start Date', select=1)
     location = fields.Many2One('calendar.location', 'Location')
     organizer = fields.Char('Organizer', states={
-        'required': If(Bool(Eval('attendees')),
-            Not(Bool(Eval('parent'))),
-            False),
-        }, depends=['attendees', 'parent'])
+            'required': If(Bool(Eval('attendees')),
+                ~Eval('parent'), False),
+            }, depends=['attendees', 'parent'])
     attendees = fields.One2Many('calendar.todo.attendee', 'todo',
             'Attendees')
     percent_complete = fields.Integer('Percent complete',
-            states={
-                'readonly': Not(In(Eval('status'),
-                    ['needs-action', 'in-process'])),
+        states={
+            'readonly': ~Eval('status').in_(['needs-action', 'in-process']),
             }, depends=['status'])
     occurences = fields.One2Many('calendar.todo', 'parent', 'Occurences',
             domain=[
@@ -61,9 +59,9 @@ class Todo(ModelSQL, ModelView):
                 'invisible': Bool(Eval('parent')),
             }, depends=['uuid', 'calendar', 'parent'])
     recurrence = fields.DateTime('Recurrence', select=1, states={
-                'invisible': Not(Bool(Eval('_parent_parent'))),
-                'required': Bool(Eval('_parent_parent')),
-                }, depends=['parent'])
+            'invisible': ~Eval('_parent_parent'),
+            'required': Bool(Eval('_parent_parent')),
+            }, depends=['parent'])
     sequence = fields.Integer('Sequence')
     parent = fields.Many2One('calendar.todo', 'Parent',
             domain=[
@@ -125,8 +123,8 @@ class Todo(ModelSQL, ModelView):
 
     def init(self, module_name):
         # Migrate from 1.4: remove classification_public
-        model_data_obj = self.pool.get('ir.model.data')
-        rule_obj = self.pool.get('ir.rule')
+        model_data_obj = Pool().get('ir.model.data')
+        rule_obj = Pool().get('ir.rule')
         with Transaction().set_user(0):
             model_data_ids = model_data_obj.search([
                 ('fs_id', '=', 'rule_group_read_todo_line3'),
@@ -148,7 +146,7 @@ class Todo(ModelSQL, ModelView):
         return 'public'
 
     def default_timezone(self):
-        user_obj = self.pool.get('res.user')
+        user_obj = Pool().get('res.user')
         user = user_obj.browse(Transaction().user)
         return user.timezone
 
@@ -197,8 +195,8 @@ class Todo(ModelSQL, ModelView):
         return True
 
     def create(self, values):
-        calendar_obj = self.pool.get('calendar.calendar')
-        collection_obj = self.pool.get('webdav.collection')
+        calendar_obj = Pool().get('calendar.calendar')
+        collection_obj = Pool().get('webdav.collection')
 
         res = super(Todo, self).create(values)
         todo = self.browse(res)
@@ -250,10 +248,11 @@ class Todo(ModelSQL, ModelView):
         return res
 
     def _todo2update(self, todo):
-        rdate_obj = self.pool.get('calendar.todo.rdate')
-        exdate_obj = self.pool.get('calendar.todo.exdate')
-        rrule_obj = self.pool.get('calendar.todo.rrule')
-        exrule_obj = self.pool.get('calendar.todo.exrule')
+        pool = Pool()
+        rdate_obj = pool.get('calendar.todo.rdate')
+        exdate_obj = pool.get('calendar.todo.exdate')
+        rrule_obj = pool.get('calendar.todo.rrule')
+        exrule_obj = pool.get('calendar.todo.exrule')
 
         res = {}
         res['summary'] = todo.summary
@@ -283,8 +282,8 @@ class Todo(ModelSQL, ModelView):
         return res
 
     def write(self, ids, values):
-        calendar_obj = self.pool.get('calendar.calendar')
-        collection_obj = self.pool.get('webdav.collection')
+        calendar_obj = Pool().get('calendar.calendar')
+        collection_obj = Pool().get('webdav.collection')
 
         cursor = Transaction().cursor
 
@@ -366,8 +365,8 @@ class Todo(ModelSQL, ModelView):
         return res
 
     def delete(self, ids):
-        attendee_obj = self.pool.get('calendar.todo.attendee')
-        collection_obj = self.pool.get('webdav.collection')
+        attendee_obj = Pool().get('calendar.todo.attendee')
+        collection_obj = Pool().get('webdav.collection')
 
         if isinstance(ids, (int, long)):
             ids = [ids]
@@ -445,15 +444,16 @@ class Todo(ModelSQL, ModelView):
         :param vtodo: the vtodo of the ical to use if None use the first one
         :return: a dictionary with values
         '''
-        category_obj = self.pool.get('calendar.category')
-        location_obj = self.pool.get('calendar.location')
-        user_obj = self.pool.get('res.user')
-        alarm_obj = self.pool.get('calendar.todo.alarm')
-        attendee_obj = self.pool.get('calendar.todo.attendee')
-        rdate_obj = self.pool.get('calendar.todo.rdate')
-        exdate_obj = self.pool.get('calendar.todo.exdate')
-        rrule_obj = self.pool.get('calendar.todo.rrule')
-        exrule_obj = self.pool.get('calendar.todo.exrule')
+        pool = Pool()
+        category_obj = pool.get('calendar.category')
+        location_obj = pool.get('calendar.location')
+        user_obj = pool.get('res.user')
+        alarm_obj = pool.get('calendar.todo.alarm')
+        attendee_obj = pool.get('calendar.todo.attendee')
+        rdate_obj = pool.get('calendar.todo.rdate')
+        exdate_obj = pool.get('calendar.todo.exdate')
+        rrule_obj = pool.get('calendar.todo.rrule')
+        exrule_obj = pool.get('calendar.todo.exrule')
 
         vtodos = []
         if not vtodo:
@@ -689,13 +689,14 @@ class Todo(ModelSQL, ModelView):
             or a calendar.todo id
         :return: an iCalendar instance of vobject
         '''
-        user_obj = self.pool.get('res.user')
-        alarm_obj = self.pool.get('calendar.todo.alarm')
-        attendee_obj = self.pool.get('calendar.todo.attendee')
-        rdate_obj = self.pool.get('calendar.todo.rdate')
-        exdate_obj = self.pool.get('calendar.todo.exdate')
-        rrule_obj = self.pool.get('calendar.todo.rrule')
-        exrule_obj = self.pool.get('calendar.todo.exrule')
+        pool = Pool()
+        user_obj = pool.get('res.user')
+        alarm_obj = pool.get('calendar.todo.alarm')
+        attendee_obj = pool.get('calendar.todo.attendee')
+        rdate_obj = pool.get('calendar.todo.rdate')
+        exdate_obj = pool.get('calendar.todo.exdate')
+        rrule_obj = pool.get('calendar.todo.rrule')
+        exrule_obj = pool.get('calendar.todo.exrule')
 
         if isinstance(todo, (int, long)):
             todo = self.browse(todo)
@@ -711,7 +712,7 @@ class Todo(ModelSQL, ModelView):
         ical = vobject.iCalendar()
         vtodo = ical.add('vtodo')
         if todo.vtodo:
-            ical.vtodo = vobject.readOne(todo.vtodo)
+            ical.vtodo = vobject.readOne(str(todo.vtodo))
             vtodo = ical.vtodo
             ical.vtodo.transformToNative()
         if todo.summary:
@@ -887,14 +888,14 @@ class TodoRDate(ModelSQL, ModelView):
         return super(TodoRDate, self).init(module_name)
 
     def create(self, values):
-        todo_obj = self.pool.get('calendar.todo')
+        todo_obj = Pool().get('calendar.todo')
         if values.get('todo'):
             # Update write_date of todo
             todo_obj.write(values['todo'], {})
         return super(TodoRDate, self).create(values)
 
     def write(self, ids, values):
-        todo_obj = self.pool.get('calendar.todo')
+        todo_obj = Pool().get('calendar.todo')
         if isinstance(ids, (int, long)):
             ids = [ids]
         todo_ids = [x.todo.id for x in self.browse(ids)]
@@ -906,8 +907,8 @@ class TodoRDate(ModelSQL, ModelView):
         return super(TodoRDate, self).write(ids, values)
 
     def delete(self, ids):
-        todo_obj = self.pool.get('calendar.todo')
-        rdate_obj = self.pool.get('calendar.date')
+        todo_obj = Pool().get('calendar.todo')
+        rdate_obj = Pool().get('calendar.date')
         if isinstance(ids, (int, long)):
             ids = [ids]
         todo_rdates = self.browse(ids)
@@ -922,15 +923,15 @@ class TodoRDate(ModelSQL, ModelView):
         return res
 
     def _date2update(self, date):
-        date_obj = self.pool.get('calendar.date')
+        date_obj = Pool().get('calendar.date')
         return date_obj._date2update(date)
 
     def date2values(self, date):
-        date_obj = self.pool.get('calendar.date')
+        date_obj = Pool().get('calendar.date')
         return date_obj.date2values(date)
 
     def date2date(self, date):
-        date_obj = self.pool.get('calendar.date')
+        date_obj = Pool().get('calendar.date')
         return date_obj.date2date(date)
 
 TodoRDate()
@@ -949,14 +950,14 @@ class TodoRRule(ModelSQL, ModelView):
             select=1, required=True)
 
     def create(self, values):
-        todo_obj = self.pool.get('calendar.todo')
+        todo_obj = Pool().get('calendar.todo')
         if values.get('todo'):
             # Update write_date of todo
             todo_obj.write(values['todo'], {})
         return super(TodoRRule, self).create(values)
 
     def write(self, ids, values):
-        todo_obj = self.pool.get('calendar.todo')
+        todo_obj = Pool().get('calendar.todo')
         if isinstance(ids, (int, long)):
             ids = [ids]
         todo_ids = [x.todo.id for x in self.browse(ids)]
@@ -968,8 +969,8 @@ class TodoRRule(ModelSQL, ModelView):
         return super(TodoRRule, self).write(ids, values)
 
     def delete(self, ids):
-        todo_obj = self.pool.get('calendar.todo')
-        rrule_obj = self.pool.get('calendar.rrule')
+        todo_obj = Pool().get('calendar.todo')
+        rrule_obj = Pool().get('calendar.rrule')
         if isinstance(ids, (int, long)):
             ids = [ids]
         todo_rrules = self.browse(ids)
@@ -984,15 +985,15 @@ class TodoRRule(ModelSQL, ModelView):
         return res
 
     def _rule2update(self, rule):
-        rule_obj = self.pool.get('calendar.rrule')
+        rule_obj = Pool().get('calendar.rrule')
         return rule_obj._rule2update(rule)
 
     def rule2values(self, rule):
-        rule_obj = self.pool.get('calendar.rrule')
+        rule_obj = Pool().get('calendar.rrule')
         return rule_obj.rule2values(rule)
 
     def rule2rule(self, rule):
-        rule_obj = self.pool.get('calendar.rrule')
+        rule_obj = Pool().get('calendar.rrule')
         return rule_obj.rule2rule(rule)
 
 TodoRRule()
@@ -1026,7 +1027,7 @@ class TodoAttendee(ModelSQL, ModelView):
             required=True, select=1)
 
     def create(self, values):
-        todo_obj = self.pool.get('calendar.todo')
+        todo_obj = Pool().get('calendar.todo')
 
         if values.get('todo'):
             # Update write_date of todo
@@ -1059,7 +1060,7 @@ class TodoAttendee(ModelSQL, ModelView):
         return res
 
     def write(self, ids, values):
-        todo_obj = self.pool.get('calendar.todo')
+        todo_obj = Pool().get('calendar.todo')
 
         if isinstance(ids, (int, long)):
             ids = [ids]
@@ -1103,8 +1104,8 @@ class TodoAttendee(ModelSQL, ModelView):
         return res
 
     def delete(self, ids):
-        todo_obj = self.pool.get('calendar.todo')
-        attendee_obj = self.pool.get('calendar.attendee')
+        todo_obj = Pool().get('calendar.todo')
+        attendee_obj = Pool().get('calendar.attendee')
 
         if isinstance(ids, (int, long)):
             ids = [ids]
@@ -1165,7 +1166,7 @@ class TodoAttendee(ModelSQL, ModelView):
         return res
 
     def copy(self, ids, default=None):
-        attendee_obj = self.pool.get('calendar.attendee')
+        attendee_obj = Pool().get('calendar.attendee')
 
         int_id = False
         if isinstance(ids, (int, long)):
@@ -1186,15 +1187,15 @@ class TodoAttendee(ModelSQL, ModelView):
         return new_ids
 
     def _attendee2update(self, attendee):
-        attendee_obj = self.pool.get('calendar.attendee')
+        attendee_obj = Pool().get('calendar.attendee')
         return attendee_obj._attendee2update(attendee)
 
     def attendee2values(self, attendee):
-        attendee_obj = self.pool.get('calendar.attendee')
+        attendee_obj = Pool().get('calendar.attendee')
         return attendee_obj.attendee2values(attendee)
 
     def attendee2attendee(self, attendee):
-        attendee_obj = self.pool.get('calendar.attendee')
+        attendee_obj = Pool().get('calendar.attendee')
         return attendee_obj.attendee2attendee(attendee)
 
 TodoAttendee()
@@ -1212,14 +1213,14 @@ class TodoAlarm(ModelSQL):
             required=True, select=1)
 
     def create(self, values):
-        todo_obj = self.pool.get('calendar.todo')
+        todo_obj = Pool().get('calendar.todo')
         if values.get('todo'):
             # Update write_date of todo
             todo_obj.write(values['todo'], {})
         return super(TodoAlarm, self).create(values)
 
     def write(self, ids, values):
-        todo_obj = self.pool.get('calendar.todo')
+        todo_obj = Pool().get('calendar.todo')
         if isinstance(ids, (int, long)):
             ids = [ids]
         todo_ids = [x.todo.id for x in self.browse(ids)]
@@ -1231,8 +1232,8 @@ class TodoAlarm(ModelSQL):
         return super(TodoAlarm, self).write(ids, values)
 
     def delete(self, ids):
-        todo_obj = self.pool.get('calendar.todo')
-        alarm_obj = self.pool.get('calendar.alarm')
+        todo_obj = Pool().get('calendar.todo')
+        alarm_obj = Pool().get('calendar.alarm')
         if isinstance(ids, (int, long)):
             ids = [ids]
         todo_alarms = self.browse(ids)
@@ -1247,11 +1248,11 @@ class TodoAlarm(ModelSQL):
         return res
 
     def valarm2values(self, alarm):
-        alarm_obj = self.pool.get('calendar.alarm')
+        alarm_obj = Pool().get('calendar.alarm')
         return alarm_obj.valarm2values(alarm)
 
     def alarm2valarm(self, alarm):
-        alarm_obj = self.pool.get('calendar.alarm')
+        alarm_obj = Pool().get('calendar.alarm')
         return alarm_obj.alarm2valarm(alarm)
 
 TodoAlarm()
